@@ -29,9 +29,14 @@ use crate::{
     ServerEventHandler,
 };
 
-use self::start_diagnostic_session::Kwp2000SessionType;
+use self::start_diagnostic_session::SessionType;
 
 pub mod start_diagnostic_session;
+pub mod ecu_reset;
+pub mod clear_diagnostic_information;
+pub mod read_status_of_dtc;
+pub mod read_dtc_by_status;
+pub mod read_ecu_identification;
 
 /// KWP Command Service IDs.
 ///
@@ -129,7 +134,7 @@ pub enum KWP2000Error {
     /// ECU fault has stopped the transfer of data
     TransferSuspended,
     /// The ECU has accepted the request, but cannot reply right now. If this error occurs,
-    /// the [KwpDiagnosticServer] will automatically stop sending tester present messages and
+    /// the [Kwp2000DiagnosticServer] will automatically stop sending tester present messages and
     /// will wait for the ECUs response. If after 2000ms, the ECU did not respond, then this error
     /// will get returned back to the function call.
     RequestCorrectlyReceivedResponsePending,
@@ -189,7 +194,7 @@ pub struct Kwp2000Cmd {
 
 impl std::fmt::Debug for Kwp2000Cmd {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("UdsCmd")
+        f.debug_struct("Kwp2000Cmd")
             .field("Cmd", &self.get_kwp_sid())
             .field("Args", &self.get_payload())
             .field("response_required", &self.response_required)
@@ -198,7 +203,7 @@ impl std::fmt::Debug for Kwp2000Cmd {
 }
 
 impl Kwp2000Cmd {
-    /// Creates a new UDS Payload
+    /// Creates a new KWP2000 Payload
     pub fn new(sid: KWP2000Command, args: &[u8], need_response: bool) -> Self {
         let mut b: Vec<u8> = Vec::with_capacity(args.len() + 1);
         b.push(sid as u8);
@@ -237,9 +242,9 @@ impl BaseServerPayload for Kwp2000Cmd {
 #[derive(Debug, Copy, Clone)]
 pub struct Kwp2000VoidHandler;
 
-impl ServerEventHandler<(), Kwp2000Cmd> for Kwp2000VoidHandler {
+impl ServerEventHandler<SessionType, Kwp2000Cmd> for Kwp2000VoidHandler {
     #[inline(always)]
-    fn on_event(&mut self, _e: ServerEvent<(), Kwp2000Cmd>) {}
+    fn on_event(&mut self, _e: ServerEvent<SessionType, Kwp2000Cmd>) {}
 }
 
 #[derive(Debug, Copy, Clone)]
@@ -274,8 +279,8 @@ impl BaseServerSettings for Kwp2000ServerOptions {
 }
 
 #[derive(Debug)]
-/// UDS Diagnostic server
-pub struct UdsDiagnosticServer {
+/// Kwp2000 Diagnostic server
+pub struct Kwp2000DiagnosticServer {
     server_running: Arc<AtomicBool>,
     settings: Kwp2000ServerOptions,
     tx: mpsc::Sender<Kwp2000Cmd>,
@@ -286,18 +291,18 @@ pub struct UdsDiagnosticServer {
     dtc_format: Option<DTCFormatType>, // Used as a cache
 }
 
-impl UdsDiagnosticServer {
+impl Kwp2000DiagnosticServer {
     /// Creates a new KWP2000 over an ISO-TP connection with the ECU
     ///
     /// On startup, this server will configure the channel with the necessary settings provided in both
     /// settings and channel_cfg
     ///
     /// ## Parameters
-    /// * settings - UDS Server settings
+    /// * settings - KWP2000 Server settings
     /// * channel - ISO-TP communication channel with the ECU
     /// * channel_cfg - The settings to use for the ISO-TP channel
     /// * event_handler - Handler for logging events happening within the server. If you don't want
-    /// to create your own handler, use [UdsVoidHandler]
+    /// to create your own handler, use [Kwp2000VoidHandler]
     pub fn new_over_iso_tp<C, E>(
         settings: Kwp2000ServerOptions,
         mut server_channel: C,
@@ -306,7 +311,7 @@ impl UdsDiagnosticServer {
     ) -> DiagServerResult<Self>
     where
         C: IsoTPChannel + 'static,
-        E: ServerEventHandler<Kwp2000SessionType, Kwp2000Cmd> + 'static,
+        E: ServerEventHandler<SessionType, Kwp2000Cmd> + 'static,
     {
         server_channel.set_iso_tp_cfg(channel_cfg)?;
         server_channel.set_ids(settings.send_id, settings.recv_id)?;
@@ -339,13 +344,14 @@ impl UdsDiagnosticServer {
                             &cmd,
                             &settings,
                             &mut server_channel,
-                            0x78,
+                            0x78, 
+                            0x21
                         ) {
                             // 0x78 - Response correctly received, response pending
                             Ok(res) => {
                                 // Set server session type
-                                if cmd.bytes[1] == Kwp2000SessionType::Passive.into()
-                                    || cmd.bytes[1] == Kwp2000SessionType::Normal.into()
+                                if cmd.bytes[1] == SessionType::Passive.into()
+                                    || cmd.bytes[1] == SessionType::Normal.into()
                                 {
                                     // Default session, disable tester present
                                     send_tester_present = false;
@@ -380,7 +386,8 @@ impl UdsDiagnosticServer {
                             &cmd,
                             &settings,
                             &mut server_channel,
-                            0x78, // UDSError::RequestCorrectlyReceivedResponsePending
+                            0x78,
+                            0x21,
                         );
                         //event_handler.on_event(&res);
                         if tx_res.send(res).is_err() {
@@ -416,7 +423,7 @@ impl UdsDiagnosticServer {
                     };
 
                     if let Err(e) =
-                        helpers::perform_cmd(addr, &cmd, &settings, &mut server_channel, 0x78)
+                        helpers::perform_cmd(addr, &cmd, &settings, &mut server_channel, 0x78, 0x21)
                     {
                         event_handler.on_event(ServerEvent::TesterPresentError(e))
                     }
@@ -444,12 +451,12 @@ impl UdsDiagnosticServer {
         })
     }
 
-    /// Returns true if the internal UDS Server is running
+    /// Returns true if the internal KWP2000 Server is running
     pub fn is_server_running(&self) -> bool {
         self.server_running.load(Ordering::Relaxed)
     }
 
-    /// Returns the current settings used by the UDS Server
+    /// Returns the current settings used by the KWP2000 Server
     pub fn get_settings(&self) -> Kwp2000ServerOptions {
         self.settings
     }
@@ -504,7 +511,7 @@ impl UdsDiagnosticServer {
         self.exec_command(cmd).map(|_| ())
     }
 
-    /// Internal command for sending UDS payload to the ECU
+    /// Internal command for sending KWP2000 payload to the ECU
     fn exec_command(&mut self, cmd: Kwp2000Cmd) -> DiagServerResult<Vec<u8>> {
         match self.tx.send(cmd) {
             Ok(_) => self.rx.recv().unwrap_or(Err(DiagError::ServerNotRunning)),
@@ -522,3 +529,8 @@ impl UdsDiagnosticServer {
         self.repeat_interval = std::time::Duration::from_millis(interval_ms as u64)
     }
 }
+
+/// Returns the KWP2000 error from a given error code
+pub fn get_description_of_ecu_error(error: u8) -> KWP2000Error {
+    error.into()
+}
\ No newline at end of file
